Domain-specific language designed to streamline the development of high-performance GPU/CPU/Accelerators kernels
This report presents the forensic synthetic code analysis of tile-ai/tilelang, a Python project with 7,301 GitHub stars. SynthScan v2.0 examined 327,538 lines of code across 1333 source files, recording 5370 pattern matches distributed across 23 syntactic categories. The overall adjusted score of 22.2 places this repository in the Moderate AI signal band.
The scanner applied 160+ deterministic lexical heuristics, multi-line block detectors, abstract syntax tree depth profilers, and a cross-file Jaccard similarity matrix to construct a statistically normalised synthetic code estimate. All matches are individually weighted by severity coefficient and contextual multiplier before summation, and the resulting headline score is temporally discounted to account for the repository's development history relative to the commercial emergence of large language model coding tooling (November 2022 onward).
This chart maps the temporal evolution of the adjusted synthetic code score across successive scan runs. An upward trajectory indicates ongoing incorporation of AI-generated code or expanding LLM-assisted scaffolding; a stable or declining trajectory may reflect active human refactoring, code removal, or the adoption of stricter authorship policies. The dashed secondary line (right axis) independently tracks total raw pattern hit count, which can diverge from the normalised score when codebase size changes significantly between scans.
Classifies detected patterns by their diagnostic confidence and structural impact. CRITICAL patterns (coefficient 10) represent definitive synthetic signatures — hallucinated imports, explicit LLM attribution metadata — virtually never produced by human authors. HIGH (5) indicates strong structural tells such as cross-file repetition or cross-linguistic idioms. MEDIUM (2) covers recognisable conversational padding and AI-specific vocabulary. LOW (1) captures subtle indicators like tautological comments and generic boilerplate that require density to carry independent signal.
This horizontal bar chart decomposes the repository's raw synthetic code score by top-level directory, allowing you to pinpoint precisely which modules or components carry the highest AI authorship density. Directories with disproportionately high scores relative to their size warrant targeted manual review: concentrated AI signatures often trace back to mass-generated configuration layers, auto-ported test suites, LLM-scaffolded boilerplate classes, or entire subsystems authored under heavy copilot assistance. Use this view to prioritise your human code-review effort.
The scanner identified 5370 distinct pattern matches across 23 syntactic categories. Each entry below represents a discrete location in the source code where the engine recorded a statistically significant AI authorship indicator. Expand any category row to inspect the individual file paths, line numbers, code snippets, and the lexical context (CODE, COMMENT, or STRING) in which each match was detected.
Reading the findings table: The Severity column indicates the diagnostic confidence level (CRITICAL / HIGH / MEDIUM / LOW). The Context column identifies whether the match occurred inside executable code, an inline comment, or a string literal — comment-context matches receive a ×1.5 weight because LLMs systematically over-annotate. The ⚡ bolt icon marks clustered matches: three or more patterns within a 10-line window, each receiving an additional ×1.5 density multiplier as dense clusters constitute far stronger evidence of synthetic authorship than isolated hits.
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW | benchmark/matmul_metal/benchmark_matmul_metal.py | 52 | def matmul_cooperative_tensor_shared_c( | CODE |
| LOW | benchmark/matmul_metal/benchmark_matmul_metal.py | 84 | def matmul_cooperative_tensor_global( | CODE |
| LOW | …arse_attention/benchmark_tilelang_block_sparse_fmha.py | 14 | def get_sparse_attn_mask_from_topk(x, topk, use_dense_for_last_block=False): | CODE |
| LOW | …arse_attention/benchmark_tilelang_block_sparse_fmha.py | 26 | def get_sparse_attn_mask_from_threshold(x, threshold, use_dense_for_last_block=False): | CODE |
| LOW | …arse_attention/benchmark_tilelang_block_sparse_fmha.py | 170 | def benchmark_topk_sparse_attention(): | CODE |
| LOW | …ksparse_attention/benchmark_torch_block_sparse_fmha.py | 9 | def get_sparse_attn_mask_from_topk(x, topk, use_dense_for_last_block=False): | CODE |
| LOW | …ksparse_attention/benchmark_torch_block_sparse_fmha.py | 21 | def get_sparse_attn_mask_from_threshold(x, threshold, use_dense_for_last_block=False): | CODE |
| LOW | …ksparse_attention/benchmark_torch_block_sparse_fmha.py | 29 | def benchmark_topk_sparse_attention(): | CODE |
| LOW | …sparse_attention/benchmark_triton_block_sparse_fmha.py | 14 | def get_sparse_attn_mask_from_topk(x, topk, use_dense_for_last_block=False): | CODE |
| LOW | …sparse_attention/benchmark_triton_block_sparse_fmha.py | 26 | def get_sparse_attn_mask_from_threshold(x, threshold, use_dense_for_last_block=False): | CODE |
| LOW | …sparse_attention/benchmark_triton_block_sparse_fmha.py | 254 | def benchmark_topk_sparse_attention(): | CODE |
| LOW | …/blocksparse_attention/benchmark_library_dense_fmha.py | 6 | def get_sparse_attn_mask_from_topk(x, topk, use_dense_for_last_block=False): | CODE |
| LOW | …/blocksparse_attention/benchmark_library_dense_fmha.py | 18 | def get_sparse_attn_mask_from_threshold(x, threshold, use_dense_for_last_block=False): | CODE |
| LOW | …/blocksparse_attention/benchmark_library_dense_fmha.py | 26 | def benchmark_topk_sparse_attention(): | CODE |
| LOW | …/skills/tilelang-semantic/scripts/scan_loop_nesting.py | 71 | def _annotations_request_pipeline(node: ast.expr) -> bool: | CODE |
| LOW | docs/programming_guides/cluster_tma.md | 64 | def make_tma_multicast_kernel(M, N, block_M, block_N, cluster_mask): | CODE |
| LOW | docs/deeplearning_operators/gemv.md | 261 | def splitk_gemv_vectorized_tvm( | CODE |
| LOW | docs/tutorials/debug_tools_for_tilelang.md | 112 | def tilelang_callback_cuda_postproc(code, _): | CODE |
| LOW⚡ | docs/tutorials/debug_tools_for_tilelang.md | 141 | def debug_print_buffer_conditional(M=16, N=16): | CODE |
| LOW⚡ | docs/tutorials/debug_tools_for_tilelang.md | 148 | def debug_print_value_conditional(M=16, N=16): | CODE |
| LOW⚡ | docs/tutorials/debug_tools_for_tilelang.md | 155 | def debug_print_register_files(M=16, N=16): | CODE |
| LOW | testing/conftest.py | 15 | def _configure_torch_extensions_dir(): | CODE |
| LOW | testing/conftest.py | 54 | def pytest_collection_modifyitems(config, items): | CODE |
| LOW | testing/python/test_version_provider.py | 46 | def test_extracted_sdist_uses_plain_version_by_default(tmp_path: Path, monkeypatch: pytest.MonkeyPatch): | CODE |
| LOW | testing/python/test_version_provider.py | 56 | def test_extracted_sdist_can_opt_into_version_label(tmp_path: Path, monkeypatch: pytest.MonkeyPatch): | CODE |
| LOW | testing/python/test_version_provider.py | 69 | def test_git_checkout_uses_version_label_by_default(tmp_path: Path, monkeypatch: pytest.MonkeyPatch): | CODE |
| LOW⚡ | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 323 | def _compact_copy_view_contract(lane: int, warp_m: int, warp_n: int, k64_word: int): | CODE |
| LOW⚡ | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 327 | def _compact_producer_contract(warp_m: int, warp_n: int): | CODE |
| LOW⚡ | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 331 | def _compact_package_consumer_byte_offsets(lane: int, warp_m: int, warp_n: int, k64_word: int): | CODE |
| LOW⚡ | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 335 | def _cutlass_issue_site_contract(site: int): | CODE |
| LOW⚡ | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 339 | def _tilelang_current_issue_site_contract(site: int): | CODE |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 259 | def _pack_semantic_scale_words(scale_bytes): | CODE |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 268 | def _expected_blockscaled_chunk_kmajor_byte_location(row: int, k16_idx: int, k64_cols: int = 4) -> tuple[int, int, int]: | CODE |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 303 | def _sfa_selector_source_lane(lane: int, scale_a_thread_id: int) -> int: | CODE |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 307 | def _sfb_selector_source_lane(lane: int, scale_b_thread_id: int) -> int: | CODE |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 353 | def test_blockscaled_chunk_kmajor_word_offset_fixed_cases(): | CODE |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 381 | def test_blockscaled_chunk_kmajor_byte_word_and_flat_offsets(): | CODE |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 402 | def test_blockscaled_chunk_kmajor_explains_compact_source_address_examples(): | CODE |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 427 | def test_compact_package_producer_contract_inverts_omma_sf_source_lane_selectors(): | CODE |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 459 | def test_current_register_package_shape_cannot_be_relabelled_as_cute_compact_slots(): | CODE |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 475 | def test_cutlass_fulltile_issue_site_contract_matches_known_static_dump_points(): | CODE |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 503 | def test_current_tilelang_issue_order_differs_from_cutlass_serpentine_order(): | CODE |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 513 | def test_sfa_compact_source_example_spans_warp_m_groups_not_one_consumer_package(): | CODE |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 533 | def test_sfb_compact_source_example_spans_b_operand_lane_groups(): | CODE |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 553 | def test_pack_blockscaled_chunk_kmajor_scale_bytes_fixed_byte_offsets(): | CODE |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 592 | def test_pack_blockscaled_chunk_kmajor_scale_bytes_matches_cutedsl_blocked_sf_layout(): | CODE |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 618 | def test_pack_blockscaled_chunk_kmajor_scale_bytes_matches_word_swizzle(): | CODE |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 638 | def test_blockscaled_chunk_kmajor_matches_current_omma_sf_selector_contract(): | CODE |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 683 | def test_compact_package_issue_table_models_omma_sf_source_lane_selectors(): | CODE |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 746 | def test_compact_package_issue_table_matches_cpp_macro_issue_order(): | CODE |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 795 | def test_frontend_package_macro_keeps_compact_selector_issue_order(): | CODE |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 811 | def test_compact_package_issue_table_matches_effective_row_helpers(): | CODE |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 825 | def test_compact_package_copy_view_contract_maps_issue_rows_to_kmajor_words(): | CODE |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 869 | def test_blockscaled_chunk_kmajor_scale_packer_rejects_invalid_shapes(): | CODE |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 976 | def test_swizzle_blockscaled_chunk_kmajor_pads_rows_to_full_tiles(): | CODE |
| LOW⚡ | …sting/python/tools/test_tilelang_tools_compile_only.py | 91 | def test_compile_kernel_source_default_cpu_c(): | STRING |
| LOW⚡ | …sting/python/tools/test_tilelang_tools_compile_only.py | 100 | def test_pass_context_config_enables_line_directives_when_supported(): | STRING |
| LOW⚡ | …sting/python/tools/test_tilelang_tools_compile_only.py | 108 | def test_line_directive_parser_reads_file_and_line(): | STRING |
| LOW⚡ | …sting/python/tools/test_tilelang_tools_compile_only.py | 113 | def test_line_markers_do_not_collide(): | STRING |
| LOW⚡ | …sting/python/tools/test_tilelang_tools_compile_only.py | 319 | def test_resolve_target_rejects_json_auto(): | STRING |
| 2294 more matches not shown… | ||||
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| MEDIUM | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 39 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 44 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM | testing/python/layout/test_tilelang_tcgen05_expand.py | 133 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM | testing/python/layout/test_tilelang_tcgen05_expand.py | 141 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/layout/test_tilelang_cute.py | 59 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/layout/test_tilelang_cute.py | 62 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/layout/test_tilelang_cute.py | 72 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/layout/test_tilelang_cute.py | 74 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/layout/test_tilelang_cute.py | 99 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/layout/test_tilelang_cute.py | 102 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/layout/test_tilelang_cute.py | 123 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/layout/test_tilelang_cute.py | 126 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/layout/test_tilelang_cute.py | 215 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/layout/test_tilelang_cute.py | 218 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/layout/test_tilelang_cute.py | 279 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/layout/test_tilelang_cute.py | 282 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/layout/test_tilelang_cute.py | 462 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/layout/test_tilelang_cute.py | 466 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/layout/test_tilelang_cute.py | 753 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/layout/test_tilelang_cute.py | 756 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/layout/test_tilelang_cute.py | 803 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/layout/test_tilelang_cute.py | 806 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/layout/test_tilelang_cute.py | 822 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/layout/test_tilelang_cute.py | 825 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/layout/test_tilelang_cute.py | 1007 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/layout/test_tilelang_cute.py | 1014 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/layout/test_tilelang_cute.py | 1053 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/layout/test_tilelang_cute.py | 1058 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM | testing/python/layout/test_tilelang_cute.py | 21 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM | testing/python/layout/test_tilelang_cute.py | 23 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM | testing/python/layout/test_tilelang_cute.py | 318 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM | testing/python/layout/test_tilelang_cute.py | 321 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM | testing/python/layout/test_tilelang_cute.py | 348 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM | testing/python/layout/test_tilelang_cute.py | 351 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/cuda/test_cuda_f32x2_intrinsics.py | 28 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/cuda/test_cuda_f32x2_intrinsics.py | 30 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/cuda/test_cuda_f32x2_intrinsics.py | 34 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/cuda/test_cuda_f32x2_intrinsics.py | 36 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/cuda/test_cuda_f32x2_intrinsics.py | 90 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/cuda/test_cuda_f32x2_intrinsics.py | 92 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/cuda/test_cuda_f32x2_intrinsics.py | 102 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/cuda/test_cuda_f32x2_intrinsics.py | 104 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/cuda/test_cuda_f32x2_intrinsics.py | 264 | # =================================================================== | COMMENT |
| MEDIUM⚡ | testing/python/cuda/test_cuda_f32x2_intrinsics.py | 266 | # =================================================================== | COMMENT |
| MEDIUM | testing/python/cuda/test_cuda_f32x2_intrinsics.py | 211 | # =================================================================== | COMMENT |
| MEDIUM | testing/python/cuda/test_cuda_f32x2_intrinsics.py | 213 | # =================================================================== | COMMENT |
| MEDIUM | testing/python/cuda/test_cuda_f32x2_intrinsics.py | 328 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM | testing/python/cuda/test_cuda_f32x2_intrinsics.py | 330 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM | testing/python/cuda/test_cuda_f32x2_intrinsics.py | 456 | # =================================================================== | COMMENT |
| MEDIUM | testing/python/cuda/test_cuda_f32x2_intrinsics.py | 458 | # =================================================================== | COMMENT |
| MEDIUM⚡ | testing/python/language/test_tilelang_language_span.py | 171 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/language/test_tilelang_language_span.py | 173 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/language/test_tilelang_language_span.py | 264 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | testing/python/language/test_tilelang_language_span.py | 266 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | …sting/python/language/test_tilelang_language_reduce.py | 422 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | …sting/python/language/test_tilelang_language_reduce.py | 424 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | …sting/python/language/test_tilelang_language_reduce.py | 1020 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM⚡ | …sting/python/language/test_tilelang_language_reduce.py | 1022 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM | …sting/python/language/test_tilelang_language_reduce.py | 13 | # --------------------------------------------------------------------------- | COMMENT |
| MEDIUM | …sting/python/language/test_tilelang_language_reduce.py | 15 | # --------------------------------------------------------------------------- | COMMENT |
| 403 more matches not shown… | ||||
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW | version_provider.py | 1 | CODE | |
| LOW | benchmark/mamba2/benchmark_mamba_chunk_scan.py | 4 | CODE | |
| LOW | cmake/generate_windows_import_lib.py | 1 | CODE | |
| LOW | cmake/find_pip_cuda.py | 13 | CODE | |
| LOW | cmake/ccache_strip_pep517.py | 27 | CODE | |
| LOW | …/skills/tilelang-semantic/scripts/scan_loop_nesting.py | 4 | CODE | |
| LOW | testing/python/test_version_provider.py | 1 | CODE | |
| LOW | testing/python/tools/test_tilelang_tools_cuda_iket.py | 1 | CODE | |
| LOW | testing/python/cache/test_tilelang_cuda_binary_cache.py | 1 | CODE | |
| LOW | testing/python/metal/test_metal_codegen.py | 2 | CODE | |
| LOW | testing/python/metal/test_metal_gemm_v2.py | 8 | CODE | |
| LOW | testing/python/target/test_tilelang_target.py | 1 | CODE | |
| LOW | testing/python/target/test_tilelang_rocm_target.py | 5 | CODE | |
| LOW | …ng/python/language/test_tilelang_language_tma_store.py | 12 | CODE | |
| LOW | …sting/python/language/test_tilelang_language_unroll.py | 3 | CODE | |
| LOW | …/language/test_tilelang_language_tma_gather_scatter.py | 5 | CODE | |
| LOW | testing/python/language/test_tilelang_language_scan.py | 1 | CODE | |
| LOW | testing/python/language/test_tilelang_language_ptr.py | 3 | CODE | |
| LOW | testing/python/language/test_tilelang_language_let.py | 2 | CODE | |
| LOW | …ing/python/language/test_tilelang_language_pipeline.py | 1 | CODE | |
| LOW | testing/python/backend/test_tilelang_backend_module.py | 1 | CODE | |
| LOW | testing/python/amd/test_tilelang_test_amd.py | 2 | CODE | |
| LOW | …sting/python/amd/test_tilelang_gemm_mfma_preshuffle.py | 5 | CODE | |
| LOW | testing/python/amd/test_tilelang_gemm_mfma_intrinsic.py | 4 | CODE | |
| LOW | testing/python/jit/test_tilelang_jit_tvm_ffi.py | 1 | CODE | |
| LOW | testing/python/jit/test_tilelang_jit_cython.py | 1 | CODE | |
| LOW | testing/python/jit/test_tilelang_jit_nvrtc.py | 1 | CODE | |
| LOW | testing/python/jit/test_tilelang_jit_nullptr.py | 2 | CODE | |
| LOW | testing/python/jit/test_tilelang_jit_cutedsl.py | 1 | CODE | |
| LOW | testing/python/jit/test_tilelang_jit_gemm_cython.py | 1 | CODE | |
| LOW | testing/python/kernel/test_tilelang_kernel_gemv_simt.py | 4 | CODE | |
| LOW | testing/python/kernel/test_tilelang_kernel_gemm_simt.py | 4 | CODE | |
| LOW | testing/python/kernel/test_tilelang_kernel_gemm.py | 1 | CODE | |
| LOW | …ing/python/kernel/test_tilelang_kernel_gemm_batched.py | 1 | CODE | |
| LOW | testing/python/debug/test_pass_events.py | 3 | CODE | |
| LOW | examples/kda/chunk_delta_h_fwd.py | 3 | CODE | |
| LOW | examples/kda/chunk_bwd_dv.py | 4 | CODE | |
| LOW | examples/kda/wy_fast_bwd.py | 3 | CODE | |
| LOW | …tion/example_tilelang_sparse_gqa_decode_varlen_mask.py | 359 | CODE | |
| LOW | …tion/example_triton_sparse_gqa_decode_varlen_indice.py | 11 | CODE | |
| LOW | …tion/example_triton_sparse_gqa_decode_varlen_indice.py | 396 | CODE | |
| LOW | …ention/example_triton_sparse_gqa_decode_varlen_mask.py | 390 | CODE | |
| LOW | …_attention/example_tilelang_sparse_gqa_decode_paged.py | 451 | CODE | |
| LOW | examples/linear_attention/example_mamba_chunk_scan.py | 4 | CODE | |
| LOW | examples/linear_attention/example_mamba_chunk_state.py | 5 | CODE | |
| LOW | examples/deepseek_v32/utils.py | 6 | CODE | |
| LOW | examples/deepseek_v32/utils.py | 7 | CODE | |
| LOW | examples/deepseek_v32/utils.py | 8 | CODE | |
| LOW | examples/deepseek_v32/utils.py | 10 | CODE | |
| LOW | examples/deepseek_v32/utils.py | 12 | CODE | |
| LOW | examples/deepseek_v32/utils.py | 13 | CODE | |
| LOW | examples/deepseek_v32/utils.py | 14 | CODE | |
| LOW | examples/deepseek_v32/utils.py | 15 | CODE | |
| LOW | examples/deepseek_v32/utils.py | 16 | CODE | |
| LOW | examples/deepseek_v32/utils.py | 17 | CODE | |
| LOW | examples/deepseek_v32/utils.py | 19 | CODE | |
| LOW | examples/gemm/example_gemm_intrinsics.py | 1 | CODE | |
| LOW | examples/gdn/example_cumsum.py | 6 | CODE | |
| LOW | examples/gdn/example_chunk_delta_h.py | 3 | CODE | |
| LOW | examples/gdn/example_chunk_delta_h.py | 23 | CODE | |
| 981 more matches not shown… | ||||
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW | version_provider.py | 44 | CODE | |
| LOW | benchmark/matmul/benchmark_matmul.py | 33 | CODE | |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 143 | CODE | |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 638 | CODE | |
| LOW | …/quantize/test_tilelang_quantize_nvfp4_scale_layout.py | 811 | CODE | |
| LOW | …g/python/analysis/test_tilelang_nested_loop_checker.py | 47 | CODE | |
| LOW | …g/python/analysis/test_tilelang_nested_loop_checker.py | 102 | CODE | |
| LOW | …g/python/analysis/test_tilelang_nested_loop_checker.py | 298 | CODE | |
| LOW | …g/python/analysis/test_tilelang_nested_loop_checker.py | 314 | CODE | |
| LOW | …g/python/analysis/test_tilelang_nested_loop_checker.py | 407 | CODE | |
| LOW | …g/python/analysis/test_tilelang_nested_loop_checker.py | 49 | CODE | |
| LOW | …g/python/analysis/test_tilelang_nested_loop_checker.py | 113 | CODE | |
| LOW | …g/python/analysis/test_tilelang_nested_loop_checker.py | 300 | CODE | |
| LOW | …g/python/analysis/test_tilelang_nested_loop_checker.py | 316 | CODE | |
| LOW | …g/python/analysis/test_tilelang_nested_loop_checker.py | 425 | CODE | |
| LOW | testing/python/metal/test_metal_codegen.py | 9 | CODE | |
| LOW | testing/python/metal/test_metal_codegen.py | 11 | CODE | |
| LOW | testing/python/metal/test_metal_codegen_linux.py | 13 | CODE | |
| LOW | testing/python/metal/test_metal_codegen_linux.py | 15 | CODE | |
| LOW | testing/python/cpu/test_tilelang_cpu_reduce.py | 50 | CODE | |
| LOW | testing/python/cpu/test_tilelang_cpu_reduce.py | 95 | CODE | |
| LOW | testing/python/cpu/test_tilelang_cpu_reduce.py | 105 | CODE | |
| LOW | testing/python/cpu/test_tilelang_cpu_gemm.py | 61 | CODE | |
| LOW | testing/python/cpu/test_tilelang_cpu_gemm.py | 62 | CODE | |
| LOW | testing/python/cpu/test_tilelang_cpu_gemm.py | 65 | CODE | |
| LOW | testing/python/llvm/test_tilelang_llvm_gemm.py | 63 | CODE | |
| LOW | testing/python/llvm/test_tilelang_llvm_gemm.py | 64 | CODE | |
| LOW | testing/python/llvm/test_tilelang_llvm_gemm.py | 67 | CODE | |
| LOW | …/python/language/test_tilelang_language_warp_reduce.py | 10 | CODE | |
| LOW | …/python/language/test_tilelang_language_warp_reduce.py | 96 | CODE | |
| LOW | …/python/language/test_tilelang_language_warp_reduce.py | 14 | CODE | |
| LOW | …/python/language/test_tilelang_language_warp_reduce.py | 97 | CODE | |
| LOW | …sting/python/language/test_tilelang_language_reduce.py | 49 | CODE | |
| LOW | …sting/python/language/test_tilelang_language_reduce.py | 671 | CODE | |
| LOW | …sting/python/language/test_tilelang_language_reduce.py | 673 | CODE | |
| LOW | …sting/python/language/test_tilelang_language_all_of.py | 7 | CODE | |
| LOW | …ing/python/language/test_tilelang_language_atom_mma.py | 48 | CODE | |
| LOW | …ing/python/language/test_tilelang_language_atom_mma.py | 142 | CODE | |
| LOW | …ing/python/language/test_tilelang_language_atom_mma.py | 246 | CODE | |
| LOW | …ing/python/language/test_tilelang_language_atom_mma.py | 82 | CODE | |
| LOW | …ing/python/language/test_tilelang_language_atom_mma.py | 169 | CODE | |
| LOW | …ing/python/language/test_tilelang_language_atom_mma.py | 269 | CODE | |
| LOW | …sting/python/language/test_tilelang_language_any_of.py | 7 | CODE | |
| LOW | …ing/python/language/test_tilelang_language_pipeline.py | 157 | CODE | |
| LOW | …ing/python/language/test_tilelang_language_pipeline.py | 181 | CODE | |
| LOW | …anguage/test_tilelang_language_nvf4_mma_block_scale.py | 259 | CODE | |
| LOW | …g/python/language/test_tilelang_language_reducer_v2.py | 612 | CODE | |
| LOW | …g/python/language/test_tilelang_language_reducer_v2.py | 1076 | CODE | |
| LOW | …g/python/language/test_tilelang_language_reducer_v2.py | 1139 | CODE | |
| LOW | …g/python/language/test_tilelang_language_reducer_v2.py | 1173 | CODE | |
| LOW | …g/python/language/test_tilelang_language_reducer_v2.py | 1211 | CODE | |
| LOW | …g/python/language/test_tilelang_language_reducer_v2.py | 1298 | CODE | |
| LOW | …g/python/language/test_tilelang_language_reducer_v2.py | 1080 | CODE | |
| LOW | …g/python/language/test_tilelang_language_reducer_v2.py | 1145 | CODE | |
| LOW | …g/python/language/test_tilelang_language_reducer_v2.py | 1180 | CODE | |
| LOW | …g/python/language/test_tilelang_language_reducer_v2.py | 1223 | CODE | |
| LOW | …g/python/language/test_tilelang_language_reducer_v2.py | 1307 | CODE | |
| LOW | testing/python/math/test_math_ieee_math.py | 40 | CODE | |
| LOW | testing/python/arith/test_arith_intset.py | 139 | CODE | |
| LOW | …sting/python/amd/test_tilelang_gemm_mfma_preshuffle.py | 16 | CODE | |
| 472 more matches not shown… | ||||
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| HIGH | benchmark/matmul_fp8/benchmark_matmul.py | 0 | a reference matrix multiplication program, used to compare performance. parameters ---------- a : torch.tensor the matri | STRING |
| HIGH | benchmark/matmul/benchmark_matmul.py | 0 | a reference matrix multiplication program, used to compare performance. parameters ---------- a : torch.tensor the matri | STRING |
| HIGH | benchmark/matmul/benchmark_matmul_sp.py | 0 | a reference matrix multiplication program, used to compare performance. parameters ---------- a : torch.tensor the matri | STRING |
| HIGH | testing/python/autotune/test_tilelang_autotune.py | 0 | a reference matrix multiplication program, used to compare performance. parameters ---------- a : torch.tensor the matri | STRING |
| HIGH | …g/python/autotune/test_tilelang_autotune_eager_mode.py | 0 | a reference matrix multiplication program, used to compare performance. parameters ---------- a : torch.tensor the matri | STRING |
| HIGH | …/python/autotune/test_tilelang_autotune_with_inputs.py | 0 | a reference matrix multiplication program, used to compare performance. parameters ---------- a : torch.tensor the matri | STRING |
| HIGH | benchmark/matmul_fp8/benchmark_matmul.py | 0 | generate a list of configuration dictionaries that will be used for tuning. parameters ---------- with_roller : bool whe | STRING |
| HIGH | benchmark/matmul/benchmark_matmul.py | 0 | generate a list of configuration dictionaries that will be used for tuning. parameters ---------- with_roller : bool whe | STRING |
| HIGH | benchmark/matmul/benchmark_matmul_sp.py | 0 | generate a list of configuration dictionaries that will be used for tuning. parameters ---------- with_roller : bool whe | STRING |
| HIGH | benchmark/matmul_fp8/benchmark_matmul.py | 0 | create an autotuned matrix multiplication kernel for matrices of shape: - a: (m, k) - b: (k, n) - c: (m, n) parameters - | STRING |
| HIGH | benchmark/matmul/benchmark_matmul.py | 0 | create an autotuned matrix multiplication kernel for matrices of shape: - a: (m, k) - b: (k, n) - c: (m, n) parameters - | STRING |
| HIGH | testing/python/autotune/test_tilelang_autotune.py | 0 | create an autotuned matrix multiplication kernel for matrices of shape: - a: (m, k) - b: (k, n) - c: (m, n) parameters - | STRING |
| HIGH | benchmark/matmul/benchmark_matmul_sp.py | 0 | create an autotuned matrix multiplication kernel for matrices of shape: - a: (m, k) - b: (k, n) - c: (m, n) parameters - | STRING |
| HIGH | benchmark/matmul_fp8/benchmark_matmul.py | 0 | the compiled tvm function for block-level matrix multiplication. - we divide the entire (m, n) domain into blocks of sha | STRING |
| HIGH | benchmark/matmul/benchmark_matmul.py | 0 | the compiled tvm function for block-level matrix multiplication. - we divide the entire (m, n) domain into blocks of sha | STRING |
| HIGH | benchmark/matmul/benchmark_matmul_sp.py | 0 | the compiled tvm function for block-level matrix multiplication. - we divide the entire (m, n) domain into blocks of sha | STRING |
| HIGH | testing/python/autotune/test_tilelang_autotune.py | 0 | the compiled tvm function for block-level matrix multiplication. - we divide the entire (m, n) domain into blocks of sha | STRING |
| HIGH | …/python/autotune/test_tilelang_autotune_with_inputs.py | 0 | the compiled tvm function for block-level matrix multiplication. - we divide the entire (m, n) domain into blocks of sha | STRING |
| HIGH | examples/kda/FLA_KDA/fla_utils.py | 0 | a decorator that caches the most recent result of a function with tensor inputs. this decorator will store the output of | STRING |
| HIGH | examples/deepseek_v32/utils.py | 0 | a decorator that caches the most recent result of a function with tensor inputs. this decorator will store the output of | STRING |
| HIGH | examples/dsa_hisa/tilelang_utils.py | 0 | a decorator that caches the most recent result of a function with tensor inputs. this decorator will store the output of | STRING |
| HIGH | examples/dsa_sparse_finetune/index.py | 0 | a decorator that caches the most recent result of a function with tensor inputs. this decorator will store the output of | STRING |
| HIGH | examples/plot_layout/fragment_mma_load_a.py | 0 | given the row index `i` and column index `j` in the fragment, | STRING |
| HIGH | examples/plot_layout/fragment_mfma_load_a.py | 0 | given the row index `i` and column index `j` in the fragment, | STRING |
| HIGH | …lelang/cuda/intrinsics/macro/mma_sp_macro_generator.py | 0 | given the row index `i` and column index `j` in the fragment, | STRING |
| HIGH | tilelang/cuda/intrinsics/macro/mma_macro_generator.py | 0 | given the row index `i` and column index `j` in the fragment, | STRING |
| HIGH | …lang/cuda/intrinsics/macro/mma_sm70_macro_generator.py | 0 | given the row index `i` and column index `j` in the fragment, | STRING |
| HIGH | tilelang/cuda/intrinsics/macro/wgmma_macro_generator.py | 0 | given the row index `i` and column index `j` in the fragment, | STRING |
| HIGH | tilelang/rocm/intrinsics/mfma_macro_generator.py | 0 | given the row index `i` and column index `j` in the fragment, | STRING |
| HIGH | examples/deepseek_v32/utils.py | 0 | calculate similarity between two tensors using a normalized dot product metric. unlike torch.testing.assert_close which | STRING |
| HIGH | examples/dsa_hisa/tilelang_utils.py | 0 | calculate similarity between two tensors using a normalized dot product metric. unlike torch.testing.assert_close which | STRING |
| HIGH | examples/dsa_sparse_finetune/utils.py | 0 | calculate similarity between two tensors using a normalized dot product metric. unlike torch.testing.assert_close which | STRING |
| HIGH | examples/deepseek_v32/utils.py | 0 | assert that two tensors are similar using a global similarity metric. key differences from torch.testing.assert_close: - | STRING |
| HIGH | examples/dsa_hisa/tilelang_utils.py | 0 | assert that two tensors are similar using a global similarity metric. key differences from torch.testing.assert_close: - | STRING |
| HIGH | examples/dsa_sparse_finetune/utils.py | 0 | assert that two tensors are similar using a global similarity metric. key differences from torch.testing.assert_close: - | STRING |
| HIGH | …nel_benchmark/tilelang_bitnet_158_int8xint2_prefill.py | 0 | template <typename t1, typename t2> __device__ void decode_i2s_to_i8s(t1 *_i2b, t2 *_i8s, const int n = 16) { // convert | STRING |
| HIGH | …rnel_benchmark/tilelang_bitnet_158_int8xint2_decode.py | 0 | template <typename t1, typename t2> __device__ void decode_i2s_to_i8s(t1 *_i2b, t2 *_i8s, const int n = 16) { // convert | STRING |
| HIGH | examples/dequantize_gemm/quantize/lop3.py | 0 | template <typename t1, typename t2> __device__ void decode_i2s_to_i8s(t1 *_i2b, t2 *_i8s, const int n = 16) { // convert | STRING |
| HIGH | …es/warp_specialize/example_warp_specialize_flashmla.py | 0 | # inputs: # - q (tensor): [batch, heads, dim] # - q_pe (tensor): [batch, heads, pe_dim] # - kv (tensor): [batch, seqlen_ | STRING |
| HIGH | examples/deepseek_mla/example_mla_decode_persistent.py | 0 | # inputs: # - q (tensor): [batch, heads, dim] # - q_pe (tensor): [batch, heads, pe_dim] # - kv (tensor): [batch, seqlen_ | STRING |
| HIGH | examples/deepseek_mla/example_mla_decode_ws.py | 0 | # inputs: # - q (tensor): [batch, heads, dim] # - q_pe (tensor): [batch, heads, pe_dim] # - kv (tensor): [batch, seqlen_ | STRING |
| HIGH | …/deepseek_mla/amd/benchmark_mla_decode_amd_tilelang.py | 0 | # inputs: # - q (tensor): [batch, heads, dim] # - q_pe (tensor): [batch, heads, pe_dim] # - kv (tensor): [batch, seqlen_ | STRING |
| HIGH | examples/deepseek_nsa/example_tilelang_nsa_bwd.py | 0 | args: q (torch.tensor): queries of shape `[b, t, hq, k]` if `head_first=false` else `[b, hq, t, k]`. k (torch.tensor): k | STRING |
| HIGH | examples/deepseek_nsa/example_triton_nsa_fwd.py | 0 | args: q (torch.tensor): queries of shape `[b, t, hq, k]` if `head_first=false` else `[b, hq, t, k]`. k (torch.tensor): k | STRING |
| HIGH | …amples/deepseek_nsa/example_tilelang_nsa_fwd_varlen.py | 0 | args: q (torch.tensor): queries of shape `[b, t, hq, k]` if `head_first=false` else `[b, hq, t, k]`. k (torch.tensor): k | STRING |
| HIGH | examples/deepseek_nsa/example_triton_nsa_bwd.py | 0 | args: q (torch.tensor): queries of shape `[b, t, hq, k]` if `head_first=false` else `[b, hq, t, k]`. k (torch.tensor): k | STRING |
| HIGH | examples/deepseek_nsa/example_triton_nsa_fwd_varlen.py | 0 | args: q (torch.tensor): queries of shape `[b, t, hq, k]` if `head_first=false` else `[b, hq, t, k]`. k (torch.tensor): k | STRING |
| HIGH | examples/deepseek_nsa/benchmark/benchmark_nsa_fwd.py | 0 | args: q (torch.tensor): queries of shape `[b, t, hq, k]` if `head_first=false` else `[b, hq, t, k]`. k (torch.tensor): k | STRING |
| HIGH | examples/deepseek_nsa/reference.py | 0 | args: q (torch.tensor): queries of shape `[b, t, hq, k]` if `head_first=false` else `[b, hq, t, k]`. k (torch.tensor): k | STRING |
| HIGH | tilelang/cuda/op/gemm/gemm_mma_sm70.py | 0 | the inner macro that loads data from shared buffers a_shared and b_shared into local fragments, then issues tensor core | STRING |
| HIGH | tilelang/cuda/op/gemm/gemm_mma.py | 0 | the inner macro that loads data from shared buffers a_shared and b_shared into local fragments, then issues tensor core | STRING |
| HIGH | tilelang/cuda/op/gemm/gemm_wgmma.py | 0 | the inner macro that loads data from shared buffers a_shared and b_shared into local fragments, then issues tensor core | STRING |
| HIGH | tilelang/cuda/op/gemm_sp/gemm_sp_mma.py | 0 | the inner macro that loads data from shared buffers a_shared and b_shared into local fragments, then issues tensor core | STRING |
| HIGH | tilelang/cuda/op/gemm_sp/gemm_sp_wgmma.py | 0 | the inner macro that loads data from shared buffers a_shared and b_shared into local fragments, then issues tensor core | STRING |
| HIGH | …lelang/cuda/intrinsics/macro/mma_sp_macro_generator.py | 0 | is_m_first: true if the thread binding is in the form of (tx, warp_n, warp_m) which represents [warp_size, block_row_war | STRING |
| HIGH | tilelang/cuda/intrinsics/macro/mma_macro_generator.py | 0 | is_m_first: true if the thread binding is in the form of (tx, warp_n, warp_m) which represents [warp_size, block_row_war | STRING |
| HIGH | …lang/cuda/intrinsics/macro/mma_sm70_macro_generator.py | 0 | is_m_first: true if the thread binding is in the form of (tx, warp_n, warp_m) which represents [warp_size, block_row_war | STRING |
| HIGH | tilelang/rocm/intrinsics/mfma_macro_generator.py | 0 | is_m_first: true if the thread binding is in the form of (tx, warp_n, warp_m) which represents [warp_size, block_row_war | STRING |
| HIGH | …lelang/cuda/intrinsics/macro/mma_sp_macro_generator.py | 0 | create a layout function for storing mma results into a fragment buffer. this layout is used in conjunction with `invers | STRING |
| HIGH | …lang/cuda/intrinsics/macro/wgmma_sp_macro_generator.py | 0 | create a layout function for storing mma results into a fragment buffer. this layout is used in conjunction with `invers | STRING |
| 39 more matches not shown… | ||||
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| HIGH | …hon/transform/test_tilelang_transform_lower_tile_op.py | 418 | the old code would leave `v_thread >= 0 && v_thread < 1` in the | STRING |
| HIGH | testing/python/transform/test_nullable_buffer_params.py | 109 | - Another (non-null) tensor argument exists, but does not mention `m` | STRING |
| HIGH | examples/dequantize_gemm/quantize/lop3.py | 720 | if constexpr (withZeros && ZerosKind == 0) | CODE |
| HIGH | examples/dequantize_gemm/quantize/lop3.py | 728 | if constexpr (withZeros && ZerosKind == 1) | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 905 | var firstVisible = null; | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 909 | if (!_activeFilter || status === _activeFilter) { | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 919 | if (!activeLink || activeLink.classList.contains('filtered-out')) { | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1016 | var limit = (evt && evt.altKey) ? 999999 : n; | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1019 | while (r && shown < limit) { | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1026 | while (r && shown < limit) { | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1036 | var table = section ? section.querySelector('table') : null; | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1044 | var table = section ? section.querySelector('table') : null; | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1085 | var _alignMode = null; | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1086 | var _pendingLeft = null; | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1087 | var _alignStatus = null; | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1097 | _pendingLeft = null; | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1098 | _alignMode = null; | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1145 | while (i < m && j < n) { | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1148 | while (i < m && j < n && a[i] === b[j]) { i++; j++; } | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1149 | blocks.push([si, sj, i - si]); | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1155 | if (si > ai || sj > bi) { | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1156 | var tag = (si > ai && sj > bi) ? 'replace' : (si > ai ? 'delete' : 'insert'); | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1157 | ops.push({ tag: tag, i1: ai + aOff, i2: si + aOff, j1: bi + bOff, j2: sj + bOff }); | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1159 | ops.push({ tag: 'equal', i1: si + aOff, i2: si + size + aOff, j1: sj + bOff, j2: sj + size + bOff }); | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1162 | if (ai < m || bi < n) { | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1163 | var tag = (ai < m && bi < n) ? 'replace' : (ai < m ? 'delete' : 'insert'); | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1164 | ops.push({ tag: tag, i1: ai + aOff, i2: m + aOff, j1: bi + bOff, j2: n + bOff }); | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1177 | rows.push('<tr>' + | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1187 | for (var x = op.i1; x < op.i2; x++) bStripped.push((beforeLines[x]||'').trim()); | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1188 | for (var y = op.j1; y < op.j2; y++) aStripped.push((afterLines[y]||'').trim()); | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1194 | for (var t = 0; t < so.i2 - so.i1; t++) matched.push([so.i1 + t, so.j1 + t]); | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1200 | for (var k = op.i1; k < op.i2; k++) { if (!mL[k]) unmatchedL.push(k); } | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1201 | for (var k = op.j1; k < op.j2; k++) { if (!mR[k]) unmatchedR.push(k); } | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1206 | if (k < gl.length && k < gr.length) all.push([gl[k], gr[k], false]); | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1206 | if (k < gl.length && k < gr.length) all.push([gl[k], gr[k], false]); | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1207 | else if (k < gl.length) all.push([gl[k], null, false]); | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1207 | else if (k < gl.length) all.push([gl[k], null, false]); | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1208 | else all.push([null, gr[k], false]); | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1208 | else all.push([null, gr[k], false]); | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1214 | while (up < unmatchedL.length && unmatchedL[up] < li) { gl.push(unmatchedL[up]); up++; } | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1214 | while (up < unmatchedL.length && unmatchedL[up] < li) { gl.push(unmatchedL[up]); up++; } | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1215 | while (vp < unmatchedR.length && unmatchedR[vp] < ri) { gr.push(unmatchedR[vp]); vp++; } | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1215 | while (vp < unmatchedR.length && unmatchedR[vp] < ri) { gr.push(unmatchedR[vp]); vp++; } | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1217 | all.push([li, ri, true]); | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1222 | var isPinned = (li === pinL && ri === pinR); | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1223 | if (li !== null && ri !== null) { | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1223 | if (li !== null && ri !== null) { | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1225 | if (diff.isWsOnly && matched) { | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1227 | rows.push('<tr' + cls + '>' + | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1234 | rows.push('<tr' + cls + '>' + | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1240 | } else if (li !== null) { | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1241 | rows.push('<tr>' + | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1246 | rows.push('<tr>' + | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1254 | rows.push('<tr>' + | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1261 | rows.push('<tr>' + | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1286 | while (i < m && j < n) { | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1288 | left.push(escHtml(before[i])); | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1289 | right.push(escHtml(after[j])); | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1298 | left.push('<span class="del-word">' + escHtml(chunk) + '</span>'); | CODE |
| HIGH⚡ | tilelang/tools/lower_trace/html.py | 1302 | while (j < n && (i >= m || sm[i][j+1] > sm[i+1][j]) && before[i] !== after[j]) { | CODE |
| 26 more matches not shown… | ||||
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW | CMakeLists.txt | 1 | # Learn a lot from the MLC - LLM Project | COMMENT |
| LOW | CMakeLists.txt | 21 | project(TILE_LANG C CXX) | COMMENT |
| LOW | CMakeLists.txt | 41 | set(CMAKE_POLICY_DEFAULT_CMP0141 NEW) | COMMENT |
| LOW | CMakeLists.txt | 61 | # Apply /EHsc and /bigobj globally so every MSVC-compatible target picks | COMMENT |
| LOW | CMakeLists.txt | 201 | # so cache would work without setting `base_dir`. | COMMENT |
| LOW | format.sh | 1 | #!/usr/bin/env bash | COMMENT |
| LOW | docs/get_started/Installation.md | 261 | # Clone + build TileLang (ROCm) | COMMENT |
| LOW | testing/python/cache/test_tilelang_kernel_cache.py | 1 | # Test Plan: Disk Cache Verification using PostProc Callback | COMMENT |
| LOW | testing/python/layout/test_tilelang_tcgen05_expand.py | 1 | # Pin ExpandTcgen05Layout against the CUTLASS Copy_Traits ground truth. | COMMENT |
| LOW | testing/python/layout/test_tilelang_tcgen05_expand.py | 121 | def test_expand_gapped_tile_issues_per_batch(): | COMMENT |
| LOW | …on/layout/test_tilelang_layout_inference_z3_context.py | 1 | # Licensed to the Apache Software Foundation (ASF) under one | COMMENT |
| LOW | …ng/python/language/test_tilelang_language_tmem_copy.py | 21 | COMMENT | |
| LOW | …/python/language/test_tilelang_language_frontend_v2.py | 61 | # with T.Kernel(128, 128) as (bx, by): | COMMENT |
| LOW | …/python/language/test_tilelang_language_frontend_v2.py | 81 | # var_20: T.float8_e8m0fnu = 1.0 | COMMENT |
| LOW | …/python/language/test_tilelang_language_frontend_v2.py | 101 | # var_16: T.float8_e4m3fn = var_16 | COMMENT |
| LOW | …/python/language/test_tilelang_language_frontend_v2.py | 141 | buf_22 = T.alloc_buffer((1,), dtype=T.bfloat16, scope="shared") # noqa F841 | COMMENT |
| LOW | …/python/language/test_tilelang_language_frontend_v2.py | 161 | # T.uint16, | COMMENT |
| LOW | …/python/language/test_tilelang_language_frontend_v2.py | 181 | # torch.long, | COMMENT |
| LOW | testing/python/arith/test_arith_simplify.py | 1 | # Licensed to the Apache Software Foundation (ASF) under one | COMMENT |
| LOW | testing/python/arith/test_arith_iter_affine_map.py | 1 | # Licensed to the Apache Software Foundation (ASF) under one | COMMENT |
| LOW | testing/python/arith/test_arith_intset.py | 1 | # Licensed to the Apache Software Foundation (ASF) under one | COMMENT |
| LOW | testing/python/amd/test_tilelang_test_amd.py | 241 | COMMENT | |
| LOW | testing/python/amd/test_tilelang_hip_codegen.py | 161 | torch.cuda.synchronize() | COMMENT |
| LOW | testing/python/amd/test_tilelang_hip_codegen.py | 261 | # T.alloc_var(init=<literal>) initialisation on HIP; | COMMENT |
| LOW | testing/python/amd/test_tilelang_hip_codegen.py | 661 | assert "this_grid().sync()" in src, f"T.sync_grid() should generate 'this_grid().sync()' but not found:\n{src}" | COMMENT |
| LOW | testing/python/amd/test_tilelang_hip_codegen.py | 781 | # | COMMENT |
| LOW | …ython/transform/test_tilelang_transform_thread_sync.py | 821 | S[tx] = T.float32(1) | COMMENT |
| LOW | …n/transform/test_tilelang_transform_make_packed_api.py | 1 | # Licensed to the Apache Software Foundation (ASF) under one | COMMENT |
| LOW | examples/aws/gemm.py | 41 | C_tmem = T.alloc_tmem([block_M, block_N], accum_dtype) | COMMENT |
| LOW | examples/aws/gemm.py | 81 | # A scope is a scheduled loop: a serial loop named by its | COMMENT |
| LOW | examples/aws/gemm.py | 101 | "copy_B_g2s", | COMMENT |
| LOW | examples/aws/flash_attention.py | 81 | # after row-max and publishing P before the row-sum. | COMMENT |
| LOW | examples/bitnet-1.58b/configuration_bitnet.py | 1 | # coding=utf-8 | COMMENT |
| LOW | examples/bitnet-1.58b/modeling_bitnet.py | 1 | # coding=utf-8 | COMMENT |
| LOW | examples/bitnet-1.58b/tokenization_bitnet.py | 1 | # coding=utf-8 | COMMENT |
| LOW | examples/dequantize_gemm/quantize/quantization.py | 1 | # Copyright 2018 The apache/tvm Authors. All Rights Reserved. | COMMENT |
| LOW | examples/dequantize_gemm/quantize/mxfp.py | 41 | for (int j = 0; j < 4; ++j) { | COMMENT |
| LOW | examples/dequantize_gemm/quantize/mxfp.py | 61 | # AMD gfx950 / HIP version of fp4->bf16 twiddling dequantization. | COMMENT |
| LOW | …/deepseek_mla/amd/benchmark_mla_decode_amd_tilelang.py | 201 | else: | COMMENT |
| LOW | tilelang/env.py | 101 | # tvm-ffi's Cython layer defaults to ``Py_BEGIN_ALLOW_THREADS`` around every | COMMENT |
| LOW | tilelang/tools/pass_visualizer/__init__.py | 21 | # NOTE: viewer (build_pass_data / emit_html / emit_txt) is intentionally NOT | COMMENT |
| LOW | tilelang/cuda/pipeline.py | 81 | mod = tilelang.transform.LegalizeNegativeIndex()(mod) | COMMENT |
| LOW | tilelang/cuda/pipeline.py | 101 | # Tile-level warp specialization: runs before layout inference so that | COMMENT |
| LOW | tilelang/cuda/pipeline.py | 141 | # Assert no reducer v2 construct survived materialization | COMMENT |
| LOW | tilelang/cuda/pipeline.py | 221 | # TODO(lei): This is a hack to make sure the | COMMENT |
| LOW | tilelang/cuda/intrinsics/layout/mma_layout.py | 301 | swizzle_bytes = min(128, row_bytes) | COMMENT |
| LOW | tilelang/cuda/intrinsics/macro/wgmma_macro_generator.py | 101 | operand or the atom-level API. | COMMENT |
| LOW | tilelang/language/tir/ir.py | 321 | # Upstream ``tvm.tir.generic.cast`` only takes a generic ``annotations`` map | COMMENT |
| LOW | tilelang/language/parser/__init__.py | 1 | # Licensed to the Apache Software Foundation (ASF) under one | COMMENT |
| LOW | tilelang/language/parser/operation.py | 1 | # Licensed to the Apache Software Foundation (ASF) under one | COMMENT |
| LOW | tilelang/language/parser/operation.py | 121 | # doc.Div <-- is overloaded | COMMENT |
| LOW | tilelang/language/parser/parser.py | 1 | # Licensed to the Apache Software Foundation (ASF) under one | COMMENT |
| LOW | tilelang/language/parser/entry.py | 1 | # Licensed to the Apache Software Foundation (ASF) under one | COMMENT |
| LOW | tilelang/language/ast/_ffi_api.py | 1 | # Licensed to the Apache Software Foundation (ASF) under one | COMMENT |
| LOW | tilelang/language/ast/__init__.py | 1 | # Licensed to the Apache Software Foundation (ASF) under one | COMMENT |
| LOW | tilelang/language/ast/ir.py | 1 | # Licensed to the Apache Software Foundation (ASF) under one | COMMENT |
| LOW | tilelang/language/eager/builder.py | 561 | else: | COMMENT |
| LOW | tilelang/language/eager/builder.py | 1001 | # def foo(): | COMMENT |
| LOW | tilelang/language/eager/ast.py | 401 | # for example: | COMMENT |
| LOW | tilelang/contrib/rocm.py | 1 | # Licensed to the Apache Software Foundation (ASF) under one | COMMENT |
| 222 more matches not shown… | ||||
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW | benchmark/matmul_metal/benchmark_matmul_metal.py | 247 | except Exception as e: | CODE |
| LOW | cmake/find_pip_cuda.py | 173 | except Exception: | CODE |
| LOW⚡ | testing/python/math/test_math_ieee_math.py | 161 | except Exception as e: | CODE |
| LOW | testing/python/arith/test_arith_hard.py | 101 | except Exception as e: | CODE |
| LOW | …/test_tilelang_transform_pipeline_barrier_ownership.py | 23 | except Exception: | CODE |
| LOW | examples/kda/FLA_KDA/fla_utils.py | 140 | except Exception: | CODE |
| LOW | examples/kda/FLA_KDA/fla_utils.py | 149 | except Exception: | CODE |
| LOW | examples/kda/FLA_KDA/fla_utils.py | 239 | except Exception: | CODE |
| MEDIUM | examples/kda/FLA_KDA/fla_utils.py | 224 | def get_all_max_shared_mem(): | CODE |
| LOW | examples/autodd/tilelang_buggy.py | 220 | except Exception as e: | CODE |
| MEDIUM | examples/autodd/tilelang_buggy.py | 221 | print(f"Error: {e}") | CODE |
| LOW | examples/autodd/tilelang_minimized_expected.py | 51 | except Exception as e: | CODE |
| MEDIUM | examples/amd/example_amd_flash_attn_bwd.py | 19 | print("Error: GPU Device is not detected") | CODE |
| MEDIUM | examples/amd/example_amd_flash_attn_fwd.py | 17 | print("Error: GPU Device is not detected") | CODE |
| LOW | examples/gdn/example_cumsum.py | 136 | except Exception as e: | CODE |
| LOW | examples/gdn/example_chunk_delta_h.py | 321 | except Exception as e: | CODE |
| LOW | examples/gdn/example_chunk_delta_h.py | 336 | except Exception as e: | CODE |
| LOW | examples/gdn/example_chunk_delta_h.py | 345 | except Exception as e: | CODE |
| LOW | examples/gdn/example_chunk_o.py | 208 | except Exception as e: | CODE |
| LOW | examples/gdn/example_wy_fast.py | 184 | except Exception as e: | CODE |
| LOW | examples/gdn/example_wy_fast.py | 190 | except Exception as e: | CODE |
| LOW⚡ | examples/gdn/example_chunk_o_bwd.py | 438 | except Exception as e: | CODE |
| LOW⚡ | examples/gdn/example_chunk_o_bwd.py | 445 | except Exception as e: | CODE |
| LOW⚡ | examples/gdn/example_chunk_o_bwd.py | 453 | except Exception as e: | CODE |
| LOW⚡ | examples/gdn/example_chunk_o_bwd.py | 461 | except Exception as e: | CODE |
| LOW | examples/gdn/example_chunk_scaled_dot_kkt.py | 164 | except Exception as e: | CODE |
| LOW⚡ | examples/gdn/example_chunk_delta_bwd.py | 360 | except Exception as e: | CODE |
| LOW⚡ | examples/gdn/example_chunk_delta_bwd.py | 366 | except Exception as e: | CODE |
| LOW⚡ | examples/gdn/example_chunk_delta_bwd.py | 372 | except Exception as e: | CODE |
| MEDIUM | examples/gdn/example_chunk_delta_bwd.py | 356 | def test_result(dh_0, dh0_0, dv2_0, dh_1, dh0_1, dv2_1, name): | CODE |
| LOW | examples/bitnet-1.58b/vllm_workspace/conftest.py | 207 | except Exception: | CODE |
| LOW | tilelang/env.py | 595 | except Exception: | CODE |
| LOW⚡ | tilelang/__init__.py | 27 | except Exception: | CODE |
| LOW⚡ | tilelang/__init__.py | 30 | except Exception: | CODE |
| LOW⚡ | tilelang/__init__.py | 38 | except Exception as exc: | CODE |
| LOW | tilelang/__init__.py | 86 | except Exception: | CODE |
| LOW | tilelang/__init__.py | 122 | except Exception: | CODE |
| LOW | tilelang/autodd.py | 642 | except Exception as _: | CODE |
| LOW | tilelang/autodd.py | 702 | except Exception as _: | CODE |
| LOW⚡ | tilelang/autodd.py | 760 | except Exception: | CODE |
| LOW⚡ | tilelang/autodd.py | 766 | except Exception as e: | CODE |
| LOW | tilelang/autodd.py | 813 | except Exception as e: | CODE |
| LOW | tilelang/errors.py | 70 | except Exception: | CODE |
| LOW | tilelang/tools/pass_timing.py | 60 | except Exception: | CODE |
| LOW | tilelang/tools/compile_only.py | 51 | except Exception: | CODE |
| LOW | tilelang/tools/compile_only.py | 249 | except Exception as exc: | CODE |
| LOW | tilelang/tools/cuda/iket/session.py | 131 | except Exception: | CODE |
| LOW | tilelang/tools/lower_trace/__init__.py | 112 | except Exception as e: | CODE |
| LOW | tilelang/tools/lower_trace/__init__.py | 179 | except Exception as exc: | CODE |
| LOW | tilelang/tools/lower_trace/__init__.py | 208 | except Exception: | CODE |
| LOW | tilelang/tools/lower_trace/core.py | 156 | except Exception: | CODE |
| LOW | tilelang/tools/lower_trace/core.py | 193 | except Exception: | CODE |
| LOW | tilelang/tools/lower_trace/core.py | 286 | except Exception as exc: | CODE |
| LOW | tilelang/tools/lower_trace/core.py | 339 | except Exception as error: | CODE |
| LOW | tilelang/tools/lower_trace/core.py | 422 | except Exception as exc: | CODE |
| LOW | tilelang/tools/lower_trace/core.py | 438 | except Exception as error: | CODE |
| LOW | tilelang/tools/lower_trace/core.py | 486 | except Exception as exc: | CODE |
| LOW | tilelang/analysis/ast_printer.py | 66 | except Exception as e: | CODE |
| LOW⚡ | tilelang/cache/kernel_cache.py | 747 | except Exception: | CODE |
| LOW | tilelang/cache/kernel_cache.py | 107 | except Exception: | CODE |
| 103 more matches not shown… | ||||
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW | benchmark/matmul_fp8/benchmark_matmul.py | 119 | CODE | |
| LOW | testing/python/language/test_tilelang_language_clamp.py | 47 | CODE | |
| LOW | testing/python/language/test_tilelang_language_clamp.py | 102 | CODE | |
| LOW | testing/python/math/test_math_ieee_math.py | 40 | CODE | |
| LOW | …sting/python/amd/test_tilelang_gemm_mfma_preshuffle.py | 16 | CODE | |
| LOW | …sting/python/amd/test_tilelang_gemm_mfma_preshuffle.py | 270 | CODE | |
| LOW | …_tilelang_transform_producer_consumer_ws_persistent.py | 34 | CODE | |
| LOW | …_tilelang_transform_producer_consumer_ws_persistent.py | 74 | CODE | |
| LOW | …_tilelang_transform_producer_consumer_ws_persistent.py | 114 | CODE | |
| LOW | …_tilelang_transform_producer_consumer_ws_persistent.py | 204 | CODE | |
| LOW | …_tilelang_transform_producer_consumer_ws_persistent.py | 257 | CODE | |
| LOW | …_tilelang_transform_producer_consumer_ws_persistent.py | 350 | CODE | |
| LOW | …/python/carver/test_tilelang_carver_recommend_hints.py | 105 | CODE | |
| LOW | examples/kda/chunk_delta_h_fwd.py | 185 | CODE | |
| LOW | examples/kda/chunk_bwd_dqkwg.py | 186 | CODE | |
| LOW | examples/kda/FLA_KDA/fla_chunk_delta.py | 470 | CODE | |
| LOW | examples/kda/FLA_KDA/fla_chunk_delta.py | 524 | CODE | |
| LOW | examples/attention_sink/example_gqa_sink_bwd_varlen.py | 670 | CODE | |
| LOW | examples/attention_sink/example_gqa_sink_bwd_bhsd.py | 26 | CODE | |
| LOW | examples/attention_sink/example_mha_sink_fwd_bhsd.py | 191 | CODE | |
| LOW | examples/attention_sink/example_gqa_sink_fwd_varlen.py | 299 | CODE | |
| LOW | examples/attention_sink/benchmark_mha_sink_fwd.py | 125 | CODE | |
| LOW | examples/attention_sink/benchmark_gqa_sink_fwd.py | 128 | CODE | |
| LOW | examples/deepseek_mhc/example_mhc_pre.py | 406 | CODE | |
| LOW | …tion/example_tilelang_sparse_gqa_decode_varlen_mask.py | 254 | CODE | |
| LOW | …tion/example_tilelang_sparse_gqa_decode_varlen_mask.py | 289 | CODE | |
| LOW | …tion/example_tilelang_sparse_gqa_decode_varlen_mask.py | 300 | CODE | |
| LOW | …tion/example_tilelang_sparse_gqa_decode_varlen_mask.py | 314 | CODE | |
| LOW | …tion/example_tilelang_sparse_gqa_decode_varlen_mask.py | 384 | CODE | |
| LOW | …tion/example_tilelang_sparse_gqa_decode_varlen_mask.py | 200 | CODE | |
| LOW | …tion/example_triton_sparse_gqa_decode_varlen_indice.py | 307 | CODE | |
| LOW | …tion/example_triton_sparse_gqa_decode_varlen_indice.py | 318 | CODE | |
| LOW | …tion/example_triton_sparse_gqa_decode_varlen_indice.py | 321 | CODE | |
| LOW | …ention/example_triton_sparse_gqa_decode_varlen_mask.py | 303 | CODE | |
| LOW | …ention/example_triton_sparse_gqa_decode_varlen_mask.py | 314 | CODE | |
| LOW | …ention/example_triton_sparse_gqa_decode_varlen_mask.py | 317 | CODE | |
| LOW | …on/example_tilelang_sparse_gqa_decode_varlen_indice.py | 264 | CODE | |
| LOW | …on/example_tilelang_sparse_gqa_decode_varlen_indice.py | 298 | CODE | |
| LOW | …on/example_tilelang_sparse_gqa_decode_varlen_indice.py | 309 | CODE | |
| LOW | …on/example_tilelang_sparse_gqa_decode_varlen_indice.py | 323 | CODE | |
| LOW | …on/example_tilelang_sparse_gqa_decode_varlen_indice.py | 375 | CODE | |
| LOW | …on/example_tilelang_sparse_gqa_decode_varlen_indice.py | 208 | CODE | |
| LOW | …_attention/example_tilelang_sparse_gqa_decode_paged.py | 305 | CODE | |
| LOW | …_attention/example_tilelang_sparse_gqa_decode_paged.py | 316 | CODE | |
| LOW | …_attention/example_tilelang_sparse_gqa_decode_paged.py | 222 | CODE | |
| LOW | examples/deepseek_v32/sparse_mla_bwd.py | 77 | CODE | |
| LOW | examples/deepseek_v32/sparse_mla_bwd.py | 289 | CODE | |
| LOW | examples/deepseek_v32/sparse_mla_bwd.py | 335 | CODE | |
| LOW | examples/deepseek_v32/sparse_mla_fwd_seesaw.py | 537 | CODE | |
| LOW | examples/deepseek_v32/sparse_mla_fwd_pipelined.py | 342 | CODE | |
| LOW | examples/deepseek_v32/sparse_mla_fwd_pipelined.py | 388 | CODE | |
| LOW | examples/deepseek_v32/sparse_mla_fwd.py | 228 | CODE | |
| LOW | examples/deepseek_v32/sparse_mla_fwd.py | 273 | CODE | |
| LOW | examples/gemm_int4/example_tilelang_gemm_int4.py | 41 | CODE | |
| LOW | examples/gemm/example_gemm_advanced_autotune.py | 118 | CODE | |
| LOW | examples/gemm/example_gemm_advanced_autotune.py | 275 | CODE | |
| LOW | examples/amd/example_amd_flash_attn_fwd.py | 52 | CODE | |
| LOW | examples/gdn/example_cumsum.py | 24 | CODE | |
| LOW | examples/gdn/example_chunk_delta_h.py | 228 | CODE | |
| LOW | examples/gdn/example_chunk_scaled_dot_kkt.py | 53 | CODE | |
| 88 more matches not shown… | ||||
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| HIGH | examples/deepseek_v32/inference/model.py | 114 | Forward pass for parallel embedding layer. Args: x (torch.Tensor): Input tensor containing | STRING |
| HIGH | examples/deepseek_v32/inference/model.py | 141 | Applies a linear transformation to the incoming data: y = xA^T + b. This function supports specialized implemen | STRING |
| HIGH | examples/gemm/example_gemm_advanced_autotune.py | 31 | Generate a list of kernel tuning configuration dictionaries for a tiled matrix-multiply. When with_roller is T | STRING |
| HIGH | examples/gemm/example_gemm_autotune.py | 23 | Generate a list of kernel tuning configuration dictionaries for a tiled matrix-multiply. When with_roller is T | STRING |
| HIGH | …equantize_gemm/example_dequant_gemm_bf16_fp4_hopper.py | 218 | Convert a 4-bit FP4 value packed in a uint8 byte into a bfloat16 value. This helper extracts t | STRING |
| HIGH | …uantize_gemm/example_dequant_gemm_bf16_mxfp4_hopper.py | 11 | Convert a 4-bit field packed in a uint8 into a bfloat16 value, applying an exponent scale. This helper extract | STRING |
| HIGH | …uantize_gemm/example_dequant_gemm_bf16_mxfp4_hopper.py | 105 | Construct and return a tiled matrix-multiply TIR kernel that multiplies A (shape MxK) by a quantized B (shape Nx(QK | STRING |
| HIGH | examples/dequantize_gemm/dequantize_utils.py | 5 | This function expects `tensor` to be a 2-D torch.Tensor of dtype `torch.uint8`. Each output element is produced by | STRING |
| HIGH | examples/dequantize_gemm/quantize/mxfp.py | 168 | Return metadata for an MXFP decoding intrinsic: function name and C source string. Validates the requested out | STRING |
| HIGH | tilelang/tileop/base.py | 66 | Compute the warp partition (m_warp, n_warp) based on the given policy. Args: M (int): The | STRING |
| HIGH | tilelang/tileop/base.py | 162 | Determine the warp policy based on the given warp partitioning. Args: m_warp (int): Number | STRING |
| HIGH | tilelang/tileop/gemm/__init__.py | 161 | Get the appropriate implementation class for the given GEMM instruction key. Args: gemm_inst: The s | STRING |
| HIGH | tilelang/utils/language.py | 171 | Retrieve the single PrimFunc from an IRModule. Args: ir_module (IRModule): The TVM IRModule to extract | STRING |
| HIGH | tilelang/language/kernel.py | 101 | Normalize a thread-block specification into a 3-D extent list. Args: threads: A thread count, a per-dimensi | STRING |
| HIGH | tilelang/language/allocate.py | 104 | Allocate a single-element variable buffer. Args: dtype (str): The data type of the buffer (e.g., 'float32', | STRING |
| HIGH | tilelang/language/customize.py | 13 | Perform a four-element signed int8 dot product accumulated into int32. Args: A: First int8 input buffer. | STRING |
| HIGH | tilelang/language/copy_op.py | 65 | Copy data between memory regions. Args: src (Union[tirx.Buffer, tirx.BufferLoad, tirx.BufferRegion]): Sourc | STRING |
| HIGH | tilelang/language/fill_op.py | 49 | Clear a buffer by filling it with zeros. Args: buffer: Either a TVM buffer or a variable that contains a bu | STRING |
| HIGH | tilelang/language/utils.py | 63 | Compute a flat (linear) index from multi-dimensional coordinates and strides. The function accepts a sequence | STRING |
| HIGH | tilelang/language/builtin.py | 459 | Wait for memory barrier parity condition. Args: mbarrier: BarrierType The memory barrier to | STRING |
| HIGH | tilelang/language/atomic.py | 42 | Perform an atomic maximum on the value stored at dst with an optional memory-order. Supports scalar/addressed | STRING |
| HIGH | tilelang/language/atomic.py | 128 | Atomically update the value at dst to the minimum of its current value and value. Supports scalar/addressed ex | STRING |
| HIGH | tilelang/language/atomic.py | 219 | Atomically add `value` into `dst`, returning a handle to the operation. Supports scalar/addressed extern atomi | STRING |
| HIGH | tilelang/language/atomic.py | 316 | Perform an atomic addition operation with double-width operands. Args: dst (BufferLikeType): Destination bu | STRING |
| HIGH | tilelang/language/atomic.py | 354 | Perform an atomic addition operation with quad-width operands. Args: dst (BufferLikeType): Destination buff | STRING |
| HIGH | tilelang/language/atomic.py | 438 | Perform an atomic store of `src` into `dst` with the given memory ordering. Parameters: dst (Buffer): | STRING |
| HIGH | tilelang/engine/param.py | 28 | Creates a KernelParam instance from a TVM Buffer object. Args: buffer: TVM Buffer object c | STRING |
| HIGH | tilelang/carver/arch/driver/cuda_driver.py | 112 | Get the number of streaming multiprocessors (SMs) on the CUDA device. Args: device_id (int, optional): | STRING |
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| MEDIUM | …ting/python/language/test_tilelang_language_subtype.py | 72 | # Create a larger tensor and slice to get non-contiguous strides | COMMENT |
| MEDIUM | examples/quickstart.py | 58 | # Define the kernel (matmul) and compile/lower it into an executable module | COMMENT |
| MEDIUM | …_attention/example_tilelang_sparse_gqa_decode_paged.py | 358 | # Create a pool of available physical blocks | COMMENT |
| MEDIUM⚡ | tilelang/autodd.py | 770 | # This class is written by Gemini | COMMENT |
| MEDIUM | tilelang/tools/plot_layout.py | 206 | # Create a rectangle patch for visualization | COMMENT |
| MEDIUM | tilelang/cache/__init__.py | 22 | # Create a map of singleton instance of KernelCaches | COMMENT |
| MEDIUM | tilelang/layout/layout.py | 26 | # Create an IterVar for each dimension in the shape | COMMENT |
| MEDIUM | tilelang/layout/layout.py | 28 | # Define an IterVar over the range [0, size) with an associated variable name | COMMENT |
| MEDIUM | tilelang/layout/fragment.py | 50 | # Create a list of IterVar objects based on shape dimensions | COMMENT |
| MEDIUM | tilelang/language/parser/__init__.py | 17 | # This file is modified from the original version, | COMMENT |
| MEDIUM | tilelang/language/parser/operation.py | 17 | # This file is modified from the original version, | COMMENT |
| MEDIUM | tilelang/language/parser/parser.py | 17 | # This file is modified from the original version, | COMMENT |
| MEDIUM | tilelang/language/parser/entry.py | 17 | # This file is modified from the original version, | COMMENT |
| MEDIUM | tilelang/language/ast/_ffi_api.py | 17 | # This file is modified from the original version, | COMMENT |
| MEDIUM | tilelang/language/ast/__init__.py | 17 | # This file is modified from the original version, | COMMENT |
| MEDIUM | tilelang/language/ast/ir.py | 17 | # This file is modified from the original version, | COMMENT |
| MEDIUM⚡ | tilelang/contrib/cutedsl/atomic.py | 112 | # Create a tensor from pointer and load elements | COMMENT |
| MEDIUM | tilelang/jit/kernel.py | 419 | # Create an adapter based on the specified execution backend. | COMMENT |
| MEDIUM | tilelang/jit/adapter/wrapper.py | 626 | # Create the host function wrapper for the CUDA kernel | COMMENT |
| MEDIUM | tilelang/jit/adapter/wrapper.py | 896 | # Create the call function wrapper for the CPU kernel | COMMENT |
| MEDIUM | tilelang/jit/adapter/nvrtc/wrapper.py | 596 | # Create the host function wrapper for the CUDA kernel | COMMENT |
| MEDIUM | tilelang/carver/matmul_analysis.py | 737 | # This function is used to get the index map for the stage3 of the | COMMENT |
| MEDIUM | tilelang/carver/template/matmul.py | 87 | # Define a reduction axis for matrix multiplication | COMMENT |
| MEDIUM | tilelang/carver/template/elementwise.py | 1 | # Import necessary modules | COMMENT |
| MEDIUM⚡ | tilelang/carver/template/elementwise.py | 47 | # Define a placeholder tensor A | COMMENT |
| MEDIUM⚡ | tilelang/carver/template/elementwise.py | 50 | # Define the element-wise computation (adding 1 to each element) | COMMENT |
| MEDIUM⚡ | tilelang/carver/template/elementwise.py | 54 | # Define the computation for B based on A | COMMENT |
| MEDIUM | tilelang/carver/template/general_reduce.py | 106 | # Create a PrimFunc from placeholders + output | COMMENT |
| MEDIUM | tilelang/carver/template/flashattention.py | 77 | # Define a reduction axis for matrix multiplication | COMMENT |
| MEDIUM | tilelang/carver/template/gemv.py | 72 | # Define a reduction axis for matrix multiplication | COMMENT |
| MEDIUM | tilelang/carver/template/base.py | 1 | # Import necessary modules and classes | COMMENT |
| MEDIUM | tilelang/carver/roller/policy/tensorcore.py | 239 | # This function is used to check whether we can implement swizzling | COMMENT |
| MEDIUM | maint/precision/compare_ops.py | 73 | # Initialize global variables | COMMENT |
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW | version_provider.py | 99 | __all__ = ["dynamic_metadata"] | CODE |
| LOW | benchmark/matmul_fp8/benchmark_matmul.py | 10 | logger = logging.getLogger(__name__) | CODE |
| LOW | benchmark/matmul/benchmark_matmul.py | 10 | logger = logging.getLogger(__name__) | CODE |
| LOW | benchmark/matmul/benchmark_matmul_sp.py | 17 | logger = logging.getLogger(__name__) | CODE |
| LOW | …g/python/autotune/test_tilelang_autotune_eager_mode.py | 9 | logger = logging.getLogger(__name__) | CODE |
| LOW | …/python/autotune/test_tilelang_autotune_with_inputs.py | 9 | logger = logging.getLogger(__name__) | CODE |
| LOW | tilelang/env.py | 14 | logger = logging.getLogger(__name__) | CODE |
| LOW | tilelang/__init__.py | 51 | logger = logging.getLogger(__name__) | CODE |
| LOW⚡ | tilelang/ir.py | 101 | def set_stmt_span(stmt, span: Span) -> None: | CODE |
| LOW⚡ | tilelang/ir.py | 110 | def set_buffer_span(buffer, span: Span) -> None: | CODE |
| LOW⚡ | tilelang/ir.py | 119 | def set_prim_func_span(func, span: Span) -> None: | CODE |
| LOW | tilelang/tools/pass_timing.py | 353 | __all__ = [ | CODE |
| LOW | tilelang/tools/Analyzer.py | 12 | logger = logging.getLogger(__name__) | CODE |
| LOW | tilelang/tools/compile_only.py | 27 | __all__ = [ | CODE |
| LOW | tilelang/tools/cuda/iket/__init__.py | 26 | __all__ = [ | CODE |
| LOW | tilelang/tools/lower_trace/__init__.py | 35 | __all__ = [ | CODE |
| LOW | tilelang/tools/lower_trace/core.py | 289 | def update_html_link(self, run_html_path: str) -> None: | CODE |
| LOW | tilelang/tools/lower_trace/core.py | 713 | __all__ = [ | CODE |
| LOW | tilelang/metal/intrinsics/__init__.py | 5 | __all__ = ["MPSIntrinEmitter"] | CODE |
| LOW | tilelang/metal/transform/mark_host_metal_context.py | 59 | __all__ = ["MarkHostMetalContext"] | CODE |
| LOW | tilelang/metal/transform/metal_fragment_to_simdgroup.py | 174 | __all__ = ["MetalFragmentToSimdgroup"] | CODE |
| LOW | tilelang/metal/transform/__init__.py | 6 | __all__ = [ | CODE |
| LOW | tilelang/cuda/language/pdl.py | 4 | __all__ = [ | CODE |
| LOW | tilelang/cuda/language/random.py | 4 | __all__ = ["rng_init", "rng_rand", "rng_rand_float"] | CODE |
| LOW | tilelang/cuda/language/intrinsics.py | 80 | __all__ = [ | CODE |
| LOW | tilelang/cuda/language/cluster.py | 6 | __all__ = [ | CODE |
| LOW | tilelang/cuda/language/print.py | 13 | __all__ = ["device_assert", "print"] | CODE |
| LOW | tilelang/cuda/language/warpgroup.py | 8 | __all__ = ["WarpSpecialize", "WarpSpecializeFrame", "ws"] | CODE |
| LOW | tilelang/cuda/transform/__init__.py | 161 | __all__ = [ | CODE |
| LOW | tilelang/autotuner/tuner.py | 58 | logger = logging.getLogger(__name__) | CODE |
| LOW | tilelang/language/math_intrinsics.py | 430 | __all__ = [ | CODE |
| LOW | tilelang/language/ws_schedule.py | 21 | __all__ = [ | CODE |
| LOW | tilelang/language/symbolics.py | 10 | __all__ = ["dynamic", "symbolic"] | CODE |
| LOW | tilelang/language/annotations.py | 11 | __all__ = [ | CODE |
| LOW | tilelang/language/tir/exports.py | 59 | __all__ = [ | CODE |
| LOW | tilelang/language/ast/ir.py | 1915 | __all__ = [ | CODE |
| LOW | tilelang/language/eager/builder.py | 34 | logger = logging.getLogger(__name__) | CODE |
| LOW | tilelang/backend/pass_pipeline/__init__.py | 3 | __all__ = [ | CODE |
| LOW | tilelang/contrib/cutedsl/gemm_tcgen05.py | 12 | __all__ = [ | CODE |
| LOW | tilelang/contrib/cutedsl/gemm_v1.py | 1 | __all__ = [ | CODE |
| LOW | tilelang/contrib/cutedsl/threadblock_swizzle.py | 1 | __all__ = [ | CODE |
| LOW | tilelang/contrib/cutedsl/reduce.py | 8 | __all__ = [ | CODE |
| LOW | tilelang/contrib/cutedsl/quantize.py | 9 | __all__ = [ | CODE |
| LOW | tilelang/contrib/cutedsl/ldsm.py | 9 | __all__ = [ | CODE |
| LOW | tilelang/contrib/cutedsl/ieee_math.py | 10 | __all__ = [ | CODE |
| LOW | tilelang/contrib/cutedsl/utils.py | 37 | __all__ = [ | CODE |
| LOW | tilelang/contrib/cutedsl/cluster.py | 7 | __all__ = [ | CODE |
| LOW | tilelang/contrib/cutedsl/grid_sync.py | 17 | __all__ = ["sync_grid"] | CODE |
| LOW | tilelang/contrib/cutedsl/warp.py | 8 | __all__ = [ | CODE |
| LOW | tilelang/contrib/cutedsl/math.py | 1 | __all__ = [ | CODE |
| LOW | tilelang/contrib/cutedsl/atomic.py | 7 | __all__ = [ | CODE |
| LOW | tilelang/contrib/cutedsl/ptx_mma.py | 25 | __all__ = [ | CODE |
| LOW | tilelang/contrib/cutedsl/cpasync.py | 3 | __all__ = [ | CODE |
| LOW | tilelang/contrib/cutedsl/gemm_v2.py | 1 | __all__ = [ | CODE |
| LOW | tilelang/instrumentation/events.py | 251 | __all__ = [ | CODE |
| LOW | tilelang/instrumentation/session.py | 277 | __all__ = [ | CODE |
| LOW | tilelang/instrumentation/__init__.py | 29 | __all__ = [ | CODE |
| LOW | tilelang/testing/__init__.py | 16 | __all__ = [ | CODE |
| LOW | tilelang/testing/__init__.py | 100 | def set_random_seed(seed: int = 42) -> None: | CODE |
| LOW | tilelang/jit/kernel.py | 33 | logger = logging.getLogger(__name__) | CODE |
| 28 more matches not shown… | ||||
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| CRITICAL | examples/kda/FLA_KDA/fla_utils.py | 118 | # return triton.runtime.driver.active.utils.get_device_properties(tensor_idx)['multiprocessor_count'] | COMMENT |
| CRITICAL | examples/kda/FLA_KDA/fla_utils.py | 122 | # return triton.runtime.driver.active.utils.get_device_properties(tensor_idx)['num_vectorcore'] | COMMENT |
| CRITICAL | examples/kda/FLA_KDA/fla_utils.py | 227 | triton.runtime.driver.active.utils.get_device_properties(i)["max_shared_mem"] for i in range(device_torch_li | CODE |
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW | format.sh | 113 | # Check if there are any uncommitted changes after all formatting steps. | COMMENT |
| LOW | …transform/test_tilelang_transform_split_host_device.py | 260 | # Check if this is a top-level dangling declaration | COMMENT |
| LOW | …transform/test_tilelang_transform_split_host_device.py | 269 | # Check if line before assume has dangling var | COMMENT |
| LOW | …tion/example_tilelang_sparse_gqa_decode_varlen_mask.py | 328 | cache_seqlens[random_index] = max_cache_seqlen # Assign cache_seqlen to ensure at least one occurrence | CODE |
| LOW | …tion/example_triton_sparse_gqa_decode_varlen_indice.py | 339 | cache_seqlens[random_index] = max_cache_seqlen # Assign cache_seqlen to ensure at least one occurrence | CODE |
| LOW | …ention/example_triton_sparse_gqa_decode_varlen_mask.py | 333 | cache_seqlens[random_index] = max_cache_seqlen # Assign cache_seqlen to ensure at least one occurrence | CODE |
| LOW | examples/deepseek_v32/sparse_mla_fwd_seesaw.py | 223 | # Check if 384 threads have already arrived at bar_q (phase0 completed), | COMMENT |
| LOW | tilelang/autotuner/tuner.py | 944 | # Check if all tunable arguments have been tuned by comparing config keys with key_kwargs_tuple | COMMENT |
| LOW | tilelang/utils/tensor.py | 57 | # Check if with dynamic symbolic shape | COMMENT |
| LOW | tilelang/language/dtypes.py | 190 | # Check if we're on HIP (AMD ROCm) or CUDA | COMMENT |
| LOW | tilelang/language/atomic.py | 237 | >>> atomic_add(counter, 1) # Increment counter by 1 | STRING |
| LOW | tilelang/contrib/cutedsl/grid_sync.py | 54 | # Check if the globals already exist. | COMMENT |
| LOW | tilelang/jit/adapter/cutedsl/adapter.py | 352 | # Check if we have a cache path (set by kernel_cache) | COMMENT |
| LOW | tilelang/jit/adapter/nvrtc/wrapper.py | 341 | # Check if any function needs L2 Persistent Map | COMMENT |
| LOW⚡ | tilelang/jit/adapter/nvrtc/__init__.py | 12 | # Check if cuda-python is available | COMMENT |
| LOW | tilelang/engine/lower.py | 36 | # Check if it's a C target | COMMENT |
| LOW | tilelang/transform/decouple_type_cast.py | 402 | # Check if the normalized body has any Cast nodes. | COMMENT |
| LOW | tilelang/carver/template/conv.py | 128 | # Check if the input position is within bounds (implicit padding with 0) | COMMENT |
| LOW | maint/scripts/run_local_ci_test.sh | 74 | # Set ROOT_DIR to the project root (two levels up from this script's directory) | COMMENT |
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW | docs/tutorials/auto_tuning.md | 19 | ### Step 1: Implement with Reserved Parameters | COMMENT |
| LOW | docs/tutorials/auto_tuning.md | 45 | ### Step 2: Generate Candidate Configurations | COMMENT |
| LOW | docs/tutorials/auto_tuning.md | 99 | ### Step 3: Compile and Benchmark | COMMENT |
| LOW | examples/fusedmoe/example_fusedmoe_tilelang.py | 44 | # Step 1: Compute gate and up logits | COMMENT |
| LOW | examples/fusedmoe/example_fusedmoe_tilelang.py | 74 | # Step 2: Compute down logits | COMMENT |
| LOW | examples/fusedmoe/example_fusedmoe_tilelang.py | 144 | # Step 1: Compute gate and up logits | COMMENT |
| LOW | examples/fusedmoe/example_fusedmoe_tilelang.py | 192 | # Step 2: Compute down logits | COMMENT |
| LOW | tilelang/jit/adapter/cutedsl/wrapper.py | 547 | // Step 1: Unload modules for all devices | COMMENT |
| LOW | tilelang/jit/adapter/cutedsl/wrapper.py | 560 | // Step 2: Release primary contexts (must execute even if module unload failed) | COMMENT |
| LOW | tilelang/jit/adapter/cutedsl/wrapper.py | 584 | // Step 3: Clear all maps | COMMENT |
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| MEDIUM | examples/attention_sink/benchmark_mha_sink_fwd.py | 81 | p = p.to(v.dtype) # We perform fp16 gemm to utilize tensor core | CODE |
| MEDIUM | examples/attention_sink/benchmark_gqa_sink_fwd.py | 82 | p = p.to(v.dtype) # We perform fp16 gemm to utilize tensor core | CODE |
| MEDIUM | tilelang/cache/kernel_cache.py | 274 | "args_repr": tuple(repr(arg) for arg in args), # Use repr to serialize arguments, may need more robust seri | CODE |
| MEDIUM | tilelang/carver/matmul_analysis.py | 526 | # step1. detect whether the function can utilize tensorcore | COMMENT |
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW | examples/fusedmoe/example_fusedmoe_tilelang.py | 44 | # Step 1: Compute gate and up logits | COMMENT |
| LOW | examples/fusedmoe/example_fusedmoe_tilelang.py | 74 | # Step 2: Compute down logits | COMMENT |
| LOW | examples/fusedmoe/example_fusedmoe_tilelang.py | 144 | # Step 1: Compute gate and up logits | COMMENT |
| LOW | examples/fusedmoe/example_fusedmoe_tilelang.py | 192 | # Step 2: Compute down logits | COMMENT |
| LOW | tilelang/jit/adapter/cutedsl/wrapper.py | 547 | // Step 1: Unload modules for all devices | COMMENT |
| LOW | tilelang/jit/adapter/cutedsl/wrapper.py | 560 | // Step 2: Release primary contexts (must execute even if module unload failed) | COMMENT |
| LOW | tilelang/jit/adapter/cutedsl/wrapper.py | 584 | // Step 3: Clear all maps | COMMENT |
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| MEDIUM | …sparse_attention/benchmark_triton_block_sparse_fmha.py | 248 | CODE | |
| MEDIUM | …ples/blocksparse_attention/block_sparse_attn_triton.py | 248 | CODE | |
| MEDIUM | examples/seer_attention/block_sparse_attn_triton.py | 243 | CODE |
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW | format.sh | 2 | # Usage: | COMMENT |
| LOW | maint/scripts/run_local_ci_test.sh | 3 | # Usage: | COMMENT |
| LOW | maint/scripts/run_perf_regression.sh | 8 | # Usage: | COMMENT |
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| MEDIUM | maint/scripts/run_perf_regression.sh | 4 | # This script orchestrates the newer Python primitives: | COMMENT |
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW | 3rdparty/hip-headers/include/hip/hip_runtime_api.h | 2500 | // TODO: implement IPC apis | COMMENT |
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW | tilelang/carver/roller/node.py | 187 | return "placeholder" | CODE |
| Severity | File | Line | Snippet | Context |
|---|---|---|---|---|
| LOW | tilelang/language/eager/ast.py | 684 | ... def my_function(x: int) -> int: | STRING |